
.. blogpost::
    :title: New modules after a year of teachings
    :keywords: ENSAE, javascript
    :date: 2015-06-06
    :categories: teachings, module

    My students used modules I did not know about.
    I added them to function
    :func:`installation_ensae <pymyinstall.packaged.packaged_config.installation_ensae>`:

    * `newspaper3k <https://pypi.python.org/pypi/newspaper3k/>`_: python library for extracting and curating articles
    * `django-audiotracks <https://pypi.python.org/pypi/django-audiotracks/>`_
    * `pyjsdl <https://github.com/jggatc/pyjsdl>`_: pygame in javascript
    * `pymunk <http://pymunk.readthedocs.org/en/latest/>`_: simulation, game and physics
    * `textblob <http://textblob.readthedocs.org/en/dev/>`_: simplified text processing
